JasonWoof Got questions, comments, patches, etc.? Contact Jason Woofenden
renamed versatile into untiled
authorAnselm R. Garbe <arg@suckless.org>
Thu, 22 Feb 2007 16:43:41 +0000 (17:43 +0100)
committerAnselm R. Garbe <arg@suckless.org>
Thu, 22 Feb 2007 16:43:41 +0000 (17:43 +0100)
client.c
config.arg.h
config.default.h
draw.c
dwm.1
dwm.h
event.c
layout.c
tag.c

index 2e443c2..4ba15c4 100644 (file)
diff --git a/draw.c b/draw.c
index 8c9b8e8..58f3998 100644 (file)
--- a/draw.c
+++ b/draw.c
@@ -81,7 +81,7 @@ drawstatus(void) {
                dc.x = x;
                if(sel) {
                        drawtext(sel->name, dc.sel);
-                       drawsquare(sel->ismax, sel->isversatile, dc.sel);
+                       drawsquare(sel->ismax, sel->isuntiled, dc.sel);
                }
                else
                        drawtext(NULL, dc.norm);
diff --git a/dwm.1 b/dwm.1
index c688945..5112422 100644 (file)
--- a/dwm.1
+++ b/dwm.1
@@ -5,14 +5,14 @@ dwm \- dynamic window manager
 .B dwm
 .RB [ \-v ]
 .SH DESCRIPTION
-dwm is a dynamic window manager for X. It manages windows in tiling and
-versatile layouts. Either layout can be applied dynamically, optimizing the
+dwm is a dynamic window manager for X. It manages windows in tiled and
+untiled layouts. Either layout can be applied dynamically, optimizing the
 environment for the application in use and the task performed.
 .P
-In tiling layout windows are managed in a master and stacking area. The master
+In tiled layout windows are managed in a master and stacking area. The master
 area contains the windows which currently need most attention, whereas the
-stacking area contains all other windows. In versatile layout windows can be
-resized and moved freely. Dialog windows are always managed versatile,
+stacking area contains all other windows. In untiled layout windows can be
+resized and moved freely. Dialog windows are always managed untiled,
 regardless of the layout applied.
 .P
 Windows are grouped by tags. Each window can be tagged with one or multiple
@@ -20,8 +20,8 @@ tags. Selecting certain tags displays all windows with these tags.
 .P
 dwm contains a small status bar which displays all available tags, the layout,
 the title of the focused window, and the text read from standard input. A
-versatile window is indicated with an empty square and a maximized
-versatile window is indicated with a filled square before the windows
+untiled window is indicated with an empty square and a maximized
+untiled window is indicated with a filled square before the windows
 title.  The selected tags are indicated with a different color. The tags of
 the focused window are indicated with a filled square in the top left
 corner.  The tags which are applied to one or more windows are indicated
@@ -40,7 +40,7 @@ is read and displayed in the status text area.
 .TP
 .B Button1
 click on a tag label to display all windows with that tag, click on the layout
-label toggles between tiling and versatile layout.
+label toggles between tiled and untiled layout.
 .TP
 .B Button3
 click on a tag label adds/removes all windows with that tag to/from the view.
@@ -57,7 +57,7 @@ Start
 .BR xterm (1).
 .TP
 .B Mod1-Return
-Zooms/cycles current window to/from master area (tiling layout only).
+Zooms/cycles current window to/from master area (tiled layout only).
 .TP
 .B Mod1-Tab
 Focus next window.
@@ -66,19 +66,19 @@ Focus next window.
 Focus previous window.
 .TP
 .B Mod1-g
-Increase master area width (tiling layout only).
+Increase master area width (tiled layout only).
 .TP
 .B Mod1-s
-Decrease master area width (tiling layout only).
+Decrease master area width (tiled layout only).
 .TP
 .B Mod1-i
-Increase the number of windows in the master area (tiling layout only).
+Increase the number of windows in the master area (tiled layout only).
 .TP
 .B Mod1-d
-Decrease the number of windows in the master area (tiling layout only).
+Decrease the number of windows in the master area (tiled layout only).
 .TP
 .B Mod1-m
-Toggles maximization of current window (versatile layout only).
+Toggles maximization of current window (untiled layout only).
 .TP
 .B Mod1-Shift-[1..n]
 Apply
@@ -97,10 +97,10 @@ tag to/from current window.
 Close focused window.
 .TP
 .B Mod1-space
-Toggle between tiling and versatile layout (affects all windows).
+Toggle between tiled and untiled layout (affects all windows).
 .TP
 .B Mod1-Shift-space
-Toggle focused window between versatile and non-versatile state (tiling layout only).
+Toggle focused window between untiled and non-untiled state (tiled layout only).
 .TP
 .B Mod1-[1..n]
 View all windows with
@@ -120,13 +120,13 @@ Quit dwm.
 .SS Mouse commands
 .TP
 .B Mod1-Button1
-Move current window while dragging (versatile layout only).
+Move current window while dragging (untiled layout only).
 .TP
 .B Mod1-Button2
-Zooms/cycles current window to/from master area (tiling layout only).
+Zooms/cycles current window to/from master area (tiled layout only).
 .TP
 .B Mod1-Button3
-Resize current window while dragging (versatile layout only).
+Resize current window while dragging (untiled layout only).
 .SH CUSTOMIZATION
 dwm is customized by creating a custom config.h and (re)compiling the source
 code. This keeps it fast, secure and simple.
diff --git a/dwm.h b/dwm.h
index 538018a..a556b73 100644 (file)
--- a/dwm.h
+++ b/dwm.h
@@ -67,7 +67,7 @@ struct Client {
        int minax, minay, maxax, maxay;
        long flags; 
        unsigned int border;
-       Bool isbanned, isfixed, ismax, isversatile;
+       Bool isbanned, isfixed, ismax, isuntiled;
        Bool *tags;
        Client *next;
        Client *prev;
@@ -105,7 +105,7 @@ extern void killclient(const char *arg);            /* kill c nicely */
 extern void manage(Window w, XWindowAttributes *wa);   /* manage new client */
 extern void resize(Client *c, int x, int y,
                int w, int h, Bool sizehints);  /* resize with given coordinates c*/
-extern void toggleversatile(const char *arg);  /* toggles focused client between versatile/and non-versatile state */
+extern void toggletiled(const char *arg);      /* toggles focused client between tiled/untiled state */
 extern void updatesizehints(Client *c);                /* update the size hint variables of c */
 extern void updatetitle(Client *c);            /* update the name of c */
 extern void unmanage(Client *c);               /* destroy c */
@@ -126,8 +126,8 @@ extern void initlayouts(void);                      /* initialize layout array */
 extern Client *nexttiled(Client *c);           /* returns tiled successor of c */
 extern void restack(void);                     /* restores z layers of all clients */
 extern void setlayout(const char *arg);                /* sets layout, -1 toggles */
-extern void togglemax(const char *arg);                /* toggles maximization of versatile client */
-extern void versatile(void);                   /* arranges all windows versatile */
+extern void togglemax(const char *arg);                /* toggles maximization of untiled client */
+extern void untile(void);                      /* arranges all windows untiled */
 extern void zoom(const char *arg);             /* zooms the focused client to master area, arg is ignored */
 
 /* main.c */
diff --git a/event.c b/event.c
index acf1b01..a442d2e 100644 (file)
--- a/event.c
+++ b/event.c
@@ -151,14 +151,14 @@ buttonpress(XEvent *e) {
                focus(c);
                if(CLEANMASK(ev->state) != MODKEY)
                        return;
-               if(ev->button == Button1 && (lt->arrange == versatile || c->isversatile)) {
+               if(ev->button == Button1 && (lt->arrange == untile || c->isuntiled)) {
                        restack();
                        movemouse(c);
                }
                else if(ev->button == Button2)
                        zoom(NULL);
                else if(ev->button == Button3
-               && (lt->arrange == versatile || c->isversatile) && !c->isfixed)
+               && (lt->arrange == untile || c->isuntiled) && !c->isfixed)
                {
                        restack();
                        resizemouse(c);
@@ -176,7 +176,7 @@ configurerequest(XEvent *e) {
                c->ismax = False;
                if(ev->value_mask & CWBorderWidth)
                        c->border = ev->border_width;
-               if(c->isfixed || c->isversatile || (lt->arrange == versatile)) {
+               if(c->isfixed || c->isuntiled || (lt->arrange == untile)) {
                        if(ev->value_mask & CWX)
                                c->x = ev->x;
                        if(ev->value_mask & CWY)
@@ -304,7 +304,7 @@ propertynotify(XEvent *e) {
                        default: break;
                        case XA_WM_TRANSIENT_FOR:
                                XGetTransientForHint(dpy, c->win, &trans);
-                               if(!c->isversatile && (c->isversatile = (getclient(trans) != NULL)))
+                               if(!c->isuntiled && (c->isuntiled = (getclient(trans) != NULL)))
                                        lt->arrange();
                                break;
                        case XA_WM_NORMAL_HINTS:
index 1e8f113..bb477d6 100644 (file)
--- a/layout.c
+++ b/layout.c
@@ -31,7 +31,7 @@ tile(void) {
                        if(c->isbanned)
                                XMoveWindow(dpy, c->win, c->x, c->y);
                        c->isbanned = False;
-                       if(c->isversatile)
+                       if(c->isuntiled)
                                continue;
                        c->ismax = False;
                        nx = wax;
@@ -148,7 +148,7 @@ initlayouts(void) {
 
 Client *
 nexttiled(Client *c) {
-       for(; c && (c->isversatile || !isvisible(c)); c = c->next);
+       for(; c && (c->isuntiled || !isvisible(c)); c = c->next);
        return c;
 }
 
@@ -160,10 +160,10 @@ restack(void) {
        drawstatus();
        if(!sel)
                return;
-       if(sel->isversatile || lt->arrange == versatile)
+       if(sel->isuntiled || lt->arrange == untile)
                XRaiseWindow(dpy, sel->win);
-       if(lt->arrange != versatile) {
-               if(!sel->isversatile)
+       if(lt->arrange != untile) {
+               if(!sel->isuntiled)
                        XLowerWindow(dpy, sel->win);
                for(c = nexttiled(clients); c; c = nexttiled(c->next)) {
                        if(c == sel)
@@ -202,7 +202,7 @@ void
 togglemax(const char *arg) {
        XEvent ev;
 
-       if(!sel || (lt->arrange != versatile && !sel->isversatile) || sel->isfixed)
+       if(!sel || (lt->arrange != untile && !sel->isuntiled) || sel->isfixed)
                return;
        if((sel->ismax = !sel->ismax)) {
                sel->rx = sel->x;
@@ -218,7 +218,7 @@ togglemax(const char *arg) {
 }
 
 void
-versatile(void) {
+untile(void) {
        Client *c;
 
        for(c = clients; c; c = c->next) {
@@ -245,7 +245,7 @@ zoom(const char *arg) {
        unsigned int n;
        Client *c;
 
-       if(!sel || lt->arrange != tile || sel->isversatile)
+       if(!sel || lt->arrange != tile || sel->isuntiled)
                return;
        for(n = 0, c = nexttiled(clients); c; c = nexttiled(c->next))
                n++;
diff --git a/tag.c b/tag.c
index 8f41d82..b8539ac 100644 (file)
--- a/tag.c
+++ b/tag.c
@@ -12,7 +12,7 @@
 typedef struct {
        const char *prop;
        const char *tags;
-       Bool isversatile;
+       Bool isuntiled;
 } Rule;
 
 typedef struct {
@@ -83,7 +83,7 @@ settags(Client *c, Client *trans) {
                                ch.res_name ? ch.res_name : "", c->name);
                for(i = 0; i < nrules; i++)
                        if(regs[i].propregex && !regexec(regs[i].propregex, prop, 1, &tmp, 0)) {
-                               c->isversatile = rule[i].isversatile;
+                               c->isuntiled = rule[i].isuntiled;
                                for(j = 0; regs[i].tagregex && j < ntags; j++) {
                                        if(!regexec(regs[i].tagregex, tags[j], 1, &tmp, 0)) {
                                                matched = True;
--- a/client.c
+++ b/client.c
@@ -203,8 +203,8 @@ manage(Window w, XWindowAttributes *wa) {
        updatetitle(c);
        for(t = clients; t && t->win != trans; t = t->next);
        settags(c, t);
-       if(!c->isversatile)
-               c->isversatile = (t != NULL) || c->isfixed;
+       if(!c->isuntiled)
+               c->isuntiled = (t != NULL) || c->isfixed;
        attach(c);
        attachstack(c);
        c->isbanned = True;
@@ -285,10 +285,10 @@ resize(Client *c, int x, int y, int w, int h, Bool sizehints) {
 }
 
 void
-toggleversatile(const char *arg) {
-       if(!sel || lt->arrange == versatile)
+toggletiled(const char *arg) {
+       if(!sel || lt->arrange == untile)
                return;
-       sel->isversatile = !sel->isversatile;
+       sel->isuntiled = !sel->isuntiled;
        lt->arrange();
 }
 
index 0740e00..72a74bf 100644 (file)
@@ -18,7 +18,7 @@
 const char *tags[] = { "1", "2", "3", "4", "5", "6", "7", "8", "9", NULL };
 #define RULES \
 static Rule rule[] = { \
/* class:instance:title regex   tags regex      isversatile */ \
        { "Firefox",                    "3",            False }, \
        { "Gimp",                       NULL,           True }, \
        { "MPlayer",                    NULL,           True }, \
@@ -30,11 +30,11 @@ static Rule rule[] = { \
 static Layout layout[] = { \
        /* symbol               function */ \
        { "[]=",                tile }, /* first entry is default */ \
-       { "><>",                versatile }, \
+       { "><>",                untile }, \
 };
 #define MASTERWIDTH            600             /* master width per thousand */
 #define NMASTER                        1               /* clients in master area */
-#define SNAP                   40              /* versatile snap pixel */
+#define SNAP                   40              /* untiled snap pixel */
 
 /* key definitions */
 #define MODKEY                 Mod1Mask
@@ -56,7 +56,7 @@ static Key key[] = { \
        { MODKEY,                       XK_k,           focusclient,    "-1" }, \
        { MODKEY,                       XK_m,           togglemax,      NULL }, \
        { MODKEY,                       XK_Return,      zoom,           NULL }, \
-       { MODKEY|ShiftMask,             XK_space,       toggleversatile,NULL }, \
+       { MODKEY|ShiftMask,             XK_space,       toggletiled,    NULL }, \
        { MODKEY|ShiftMask,             XK_c,           killclient,     NULL }, \
        { MODKEY,                       XK_0,           view,           NULL }, \
        { MODKEY,                       XK_1,           view,           "0" }, \
index d629899..ed4447e 100644 (file)
@@ -20,7 +20,7 @@ const char *tags[] = { "1", "2", "3", "4", "5", "6", "7", "8", "9", NULL };
  * xprop | awk -F '"' '/^WM_CLASS/ { printf("%s:%s:",$4,$2) }; /^WM_NAME/ { printf("%s\n",$2) }' */
 #define RULES \
 static Rule rule[] = { \
/* class:instance:title regex   tags regex      isversatile */ \
        { "Gimp",                       NULL,           True }, \
        { "MPlayer",                    NULL,           True }, \
        { "Acroread",                   NULL,           True }, \
@@ -31,11 +31,11 @@ static Rule rule[] = { \
 static Layout layout[] = { \
        /* symbol               function */ \
        { "[]=",                tile }, /* first entry is default */ \
-       { "><>",                versatile }, \
+       { "><>",                untile }, \
 };
 #define MASTERWIDTH            600             /* master width per thousand */
 #define NMASTER                        1               /* clients in master area */
-#define SNAP                   20              /* versatile snap pixel */
+#define SNAP                   20              /* untiled snap pixel */
 
 /* key definitions */
 #define MODKEY                 Mod1Mask
@@ -52,7 +52,7 @@ static Key key[] = { \
        { MODKEY|ShiftMask,             XK_Tab,         focusclient,    "-1" }, \
        { MODKEY,                       XK_m,           togglemax,      NULL }, \
        { MODKEY,                       XK_Return,      zoom,           NULL }, \
-       { MODKEY|ShiftMask,             XK_space,       toggleversatile,NULL }, \
+       { MODKEY|ShiftMask,             XK_space,       toggletiled,    NULL }, \
        { MODKEY|ShiftMask,             XK_c,           killclient,     NULL }, \
        { MODKEY,                       XK_0,           view,           NULL }, \
        { MODKEY,                       XK_1,           view,           "0" }, \
@@ -18,7 +18,7 @@
 #define RULES \
 static Rule rule[] = { \
-       /* class:instance:title regex   tags regex      isversatile */ \
+       /* class:instance:title regex   tags regex      isuntiled */ \
        { "Firefox",                    "3",            False }, \
        { "Gimp",                       NULL,           True }, \
@@ -20,7 +20,7 @@ const char *tags[] = { "1", "2", "3", "4", "5", "6", "7", "8", "9", NULL };
 #define RULES \
 static Rule rule[] = { \
-       /* class:instance:title regex   tags regex      isversatile */ \
+       /* class:instance:title regex   tags regex      isuntiled */ \
        { "Gimp",                       NULL,           True }, \
        { "MPlayer",                    NULL,           True }, \